"""Global constants shared across trading and ETL modules."""

OPTION_TYPES = ["C", "P"]

# Day-count conventions
TRADING_DAYS_PER_YEAR: int = 252
CALENDAR_DAYS_PER_YEAR: int = 365

# Column mappings or labels
OPTION_TYPE_LABELS = {"C": "Call", "P": "Put"}
